@@ -6,19 +6,18 @@
  *  linux@codehelp.co.uk
  ****************************************************************************/
 /*
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    This package is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
  
 #include "config.h"
@@ -28,6 +27,7 @@
 #include <glib/gprintf.h>
 #include <qof.h>
 #include <math.h>
+#include <locale.h>
  /* GTK and GPE includes */
 #include <gtk/gtkmain.h>
 #include <gpe/pixmaps.h>
@@ -38,6 +38,8 @@
 #include "gpe-expenses.h"
 #include "qof-expenses.h"
 
+#define _(String) gettext (String)
+
 /** Used as a default. qof-expense sorts out the rest. */
 #define SHOW_DECIMAL_PLACES 2
 
@@ -307,7 +309,8 @@ edit_expense (GtkWidget G_GNUC_UNUSED *w, GpeExpenseData *context)
 	{
 		gchar *check;
 
-		gtk_combo_box_append_text (context->edit_type_list, ExpenseTypeasString(i));
+		gtk_combo_box_append_text (context->edit_type_list, 
+			dgettext(LIBRARY_GETTEXT_PACKAGE, ExpenseTypeasString(i)));
 		check = qof_util_param_to_string(context->entity, param);
 		if(0 == safe_strcmp(check, ExpenseTypeasString(i)))
 		{
@@ -328,7 +331,8 @@ edit_expense (GtkWidget G_GNUC_UNUSED *w, GpeExpenseData *context)
 	while((0 != safe_strcmp(ExpensePaymentasString(i), "")) &&
 		(!mileage))
 	{
-		gtk_combo_box_append_text(context->payment_list, ExpensePaymentasString(i));
+		gtk_combo_box_append_text(context->payment_list, 
+			dgettext(LIBRARY_GETTEXT_PACKAGE, ExpensePaymentasString(i)));
 		i++;
 	}
 	gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(context->payment_list), 1, 
@@ -438,20 +442,18 @@ open_about_dialog (void)
 		"categories, expense types (mileage, meals, parking, etc.), "
 		"notes and currency selection."));
 	gtk_about_dialog_set_license (ab,
-		"  This program is free software; you can redistribute it and/or modify\n"
-		"  it under the terms of the GNU General Public License as published by\n"
-		"  the Free Software Foundation; either version 2 of the License, or\n"
-		"  (at your option) any later version.\n"
+		" This package is free software; you can redistribute it and/or modify\n"
+		" it under the terms of the GNU General Public License as published by\n"
+		" the Free Software Foundation; either version 3 of the License, or\n"
+		" (at your option) any later version.\n"
 		"\n"
-		"  This program is distributed in the hope that it will be useful,\n"
-		"  but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-		"  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-		"  GNU General Public License for more details.\n"
- 		"\n"
-		"  You should have received a copy of the GNU General Public License\n"
-		"  along with this program; if not, write to the Free Software\n"
-		"  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, "
-		"MA 02110-1301, USA.\n");
+		" This program is distributed in the hope that it will be useful,\n"
+		" but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+		" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+		" GNU General Public License for more details.\n"
+		"\n"
+		" You should have received a copy of the GNU General Public License\n"
+		" along with this program.  If not, see <http://www.gnu.org/licenses/>.\n");
 	gtk_about_dialog_set_website (ab, "http://gpe-expenses.sourceforge.net/");
 	gtk_about_dialog_set_authors (ab, authors);
 	gtk_about_dialog_set_translator_credits (ab, _("translator-credits"));
@@ -475,7 +477,7 @@ exp_show_entities(QofEntity *ent, gpointer data)
 	QofNumeric amount, (*numeric_getter) (QofEntity*, const QofParam*);
 	GtkTreeIter      ent_data;
 	const QofParam   *param;
-	gchar            *type, *symbol, *date_string;
+	gchar            *type, *symbol, *date_string, *dis_string;
 	gdouble           d_amount;
 
 	context = (GpeExpenseData*)data;
@@ -485,14 +487,15 @@ exp_show_entities(QofEntity *ent, gpointer data)
 	param = qof_class_get_parameter(GPE_QOF_EXPENSES, EXP_DATE);
 	qt = (QofTime*)param->param_getfcn (ent, param);
 	qd = qof_date_from_qtime (qt);
-	/** \todo Use a locale-sensitive format? */
-	date_string = qof_date_print (qd, QOF_DATE_FORMAT_UK);
+	date_string = qof_date_print (qd, QOF_DATE_FORMAT_LOCALE);
 	qof_date_free (qd);
 	param = qof_class_get_parameter(GPE_QOF_EXPENSES, EXP_TYPE);
-	type = qof_util_param_to_string(ent, param);
+	dis_string = param->param_getfcn(ent, param);
+	type = dgettext(LIBRARY_GETTEXT_PACKAGE, dis_string);
+//	qof_util_param_to_string(ent, param);
 	/* If Mileage, use ExpenseDistance,
 	else use ExpenseCustomCurrency->symbol */
-	if(0 == safe_strcmp(type, "Mileage"))
+	if(0 == safe_strcmp(dis_string, "Mileage"))
 	{
 		gint unit;
 		/* EXP_DISTANCE */
@@ -616,15 +619,29 @@ change_amount (GtkCellRendererText G_GNUC_UNUSED *cell,
 	gchar *numeric_char;
 	gdouble d_amount;
 	gint precision;
+	/* detect local currency */
+	GpeCurrency * c;
+	struct lconv lc;
+	gchar * sy;
+	guint def_pq_code;
 
 	context = (GpeExpenseData*)data;
 	g_return_if_fail(context);
 	ENTER (" ");
+	def_pq_code = -1;
 	qe = (Expense_t*)context->entity;
 	param = qof_class_get_parameter(GPE_QOF_EXPENSES, EXP_CURRENCY);
 	i32_setter = (void(*)(QofEntity*, gint32))param->param_setfcn;
-	/** \todo don't use 22 as a default */
-	if(i32_setter != NULL) { i32_setter(context->entity, 22); }
+	/* use locale currency */
+	lc = *localeconv();
+	DEBUG (" sym=%s", lc.currency_symbol);
+	sy = g_strdup (lc.int_curr_symbol);
+	sy = g_strstrip (sy);
+	c = gpe_currency_lookup_name ((QofInstance*)context->entity, sy);
+	if (c)
+		def_pq_code = c->pq_code;
+	g_free (sy);
+	if(i32_setter != NULL) { i32_setter(context->entity, def_pq_code); }
 	param = qof_class_get_parameter(GPE_QOF_EXPENSES, EXP_AMOUNT);
 	numeric_setter = (void(*)(QofEntity*, QofNumeric))param->param_setfcn;
 	d_amount = 0.00;
@@ -816,16 +833,30 @@ open_new_expense (GtkWidget G_GNUC_UNUSED *w, GpeExpenseData *context)
 	QofBook      *book;
 	const QofParam *param;
 	void (*i32_setter)       (QofEntity*, gint32);
+	/* detect local currency */
+	GpeCurrency * c;
+	struct lconv lc;
+	gchar * sy;
+	guint def_pq_code;
 
 	g_return_if_fail(context);
+	def_pq_code = -1;
 	book = qof_session_get_book(context->qof.input_session);
 	inst = (QofInstance*)qof_object_new_instance(GPE_QOF_EXPENSES, book);
 	context->entity = &inst->entity;
-	/** \todo implement preferred currency */
+	/* use locale currency */
+	lc = *localeconv();
+	DEBUG (" sym=%s", lc.currency_symbol);
+	sy = g_strdup (lc.int_curr_symbol);
+	sy = g_strstrip (sy);
+	c = gpe_currency_lookup_name (inst, sy);
+	if (c)
+		def_pq_code = c->pq_code;
+	g_free (sy);
 	param = qof_class_get_parameter (GPE_QOF_EXPENSES, EXP_CURRENCY);
 	i32_setter = (void(*)(QofEntity*, gint32))param->param_setfcn;
 	qof_util_param_edit ((QofInstance*)context->entity, param);
-	i32_setter(context->entity, 22);
+	i32_setter(context->entity, def_pq_code);
 	qof_util_param_commit ((QofInstance*)context->entity, param);
 	gtk_list_store_append(context->list_store, &ent_data);
 	exp_refresh_list(context);
