@@ -5,27 +5,29 @@
  *  Copyright  2004-2005  Neil Williams  <linux@codehelp.co.uk>
  ****************************************************************************/
 /*
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    This package is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
   */
+
+#include "config.h"
 #include <stdlib.h>
 #include <glib.h>
-#include <glib/gi18n.h>
+#include <libintl.h>
 #include <glib/gprintf.h>
 #include <qof.h>
-#include "qof-main.h"
+#include <locale.h>
 #include "qof-expenses.h"
+#define _(String) dgettext (LIBRARY_GETTEXT_PACKAGE, String)
 
 static QofLogModule log_module = GPE_MOD_EXP;
 
@@ -33,9 +35,43 @@ AS_STRING_FUNC  (ExpenseDistance, DISTANCE_LIST)
 FROM_STRING_FUNC(ExpenseDistance, DISTANCE_LIST)
 AS_STRING_FUNC  (ExpensePayment, PAYMENT_TYPE_LIST)
 FROM_STRING_FUNC(ExpensePayment, PAYMENT_TYPE_LIST)
+/* leave the macro in place to support types.
+ allow translation by mapping the gcc -E output.
+*/
 AS_STRING_FUNC  (ExpenseType, EXPENSE_TYPE_LIST)
 FROM_STRING_FUNC(ExpenseType, EXPENSE_TYPE_LIST)
 
+/** \brief Copy of qof-main function
+
+Copied into qof-expenses library to prevent a spurious
+dependency.
+*/
+static gchar *
+qof_main_make_utf8 (gchar * string)
+{
+	gchar *value;
+
+	if (!string)
+		return NULL;
+	if (g_utf8_validate (string, -1, NULL))
+		return string;
+	value = g_locale_to_utf8 (string, -1, NULL, NULL, NULL);
+	if (!value)
+	{
+		PWARN (" unable to convert from locale %s", string);
+		PINFO ("trying to convert from ISO-8859-15.");
+		value = g_convert (string, -1, "UTF-8", "ISO-8859-15",
+			NULL, NULL, NULL);
+		if (!value)
+		{
+			PERR (" conversion failed");
+			return string;
+		}
+		return value;
+	}
+	return value;
+}
+
 /** \brief Currency Table data
 	
 Table relating the currencies[5] to the actual currency names, mnemonics
@@ -422,13 +458,15 @@ check_name (gpointer G_GNUC_UNUSED key, gpointer value, gpointer data)
 }
 
 GpeCurrency*
-gpe_currency_lookup_name (QofInstance G_GNUC_UNUSED * inst, gchar * mnemonic)
+gpe_currency_lookup_name (QofInstance * inst, gchar * mnemonic)
 {
 	GpeCurrency *currency;
 
 	currency = NULL;
+	if(!gpe_currency_table) populate_currencies();
 	currency = (GpeCurrency*) g_hash_table_find 
 		(gpe_currency_table, check_name, mnemonic);
+	gpe_currency_lookup(inst, currency->pq_code);
 	return currency;
 }
 
@@ -934,7 +972,10 @@ ExpensesRegister (void)
 	 { NULL, NULL, NULL, NULL, NULL },
 	};
 
+	bindtextdomain (LIBRARY_GETTEXT_PACKAGE, LOCALE_DIR);
+
 	qof_class_register (GPE_QOF_EXPENSES, NULL, params);
+	if(!gpe_currency_table) populate_currencies();
 
 	return qof_object_register (&expenses_object_def);
 }
